@@ -110,3 +110,28 @@ void TimeZoneTest::shouldGenerateVCard3()
                           "END:VCARD\r\n\r\n");
     QCOMPARE(ba, expected);
 }
+
+void TimeZoneTest::shouldGenerateVCard4()
+{
+    //TODO fixme.
+    KContacts::Addressee::List lst;
+    KContacts::Addressee addr;
+    addr.setEmails(QStringList() << QStringLiteral("foo@kde.org"));
+    addr.setUid(QStringLiteral("testuid"));
+    KContacts::TimeZone timezone;
+
+    timezone.setOffset(2);
+    addr.setTimeZone(timezone);
+
+    lst << addr;
+    KContacts::VCardTool vcard;
+    const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
+    const QByteArray expected("BEGIN:VCARD\r\n"
+                              "VERSION:4.0\r\n"
+                              "EMAIL:foo@kde.org\r\n"
+                              "N:;;;;\r\n"
+                              "TZ:+00:02\r\n"
+                              "UID:testuid\r\n"
+                              "END:VCARD\r\n\r\n");
+    QCOMPARE(ba, expected);
+}
