@@ -23,8 +23,8 @@
 #include <klocalizedstring.h>
 #include <krandom.h>
 
-#include <QtCore/QDataStream>
-#include <QtCore/QSharedData>
+#include <QDataStream>
+#include <QSharedData>
 
 using namespace KContacts;
 
@@ -251,17 +251,16 @@ QString PhoneNumber::typeLabel(Type type)
 
 QString PhoneNumber::toString() const
 {
-    QString str;
-
-    str += QLatin1String("PhoneNumber {\n");
+    QString str = QLatin1String("PhoneNumber {\n");
     str += QStringLiteral("    Id: %1\n").arg(d->mId);
     str += QStringLiteral("    Type: %1\n").arg(typeLabel(d->mType));
     if (!d->mParameters.isEmpty()) {
-        QMapIterator<QString, QStringList> i(d->mParameters);
         QString param;
-        while (i.hasNext()) {
-            i.next();
-            param += QStringLiteral("%1 %2").arg(i.key(), i.value().join(QLatin1Char(',')));
+        QMap<QString, QStringList>::const_iterator it = d->mParameters.constBegin();
+        const QMap<QString, QStringList>::const_iterator end = d->mParameters.constEnd();
+        while (it != end) {
+            param += QStringLiteral("%1 %2").arg(it.key(), it.value().join(QLatin1Char(',')));
+            ++it;
         }
         str += QStringLiteral("    parameters: %1\n").arg(param);
     }
